#!/usr/bin/perl -w

use strict;
use lib qw( /usr/sausalito/perl );
use CCE;

my $cce = new CCE( 'Domain' => 'base-network' );

$cce->connectfd();

my $system = $cce->event_object();
my ($ok, $sysnet) = $cce->get($cce->event_oid(), 'Network');

if (not $ok) {
	$cce->warn("cantGetNetwork");
	$cce->bye("FAIL");
	exit(1);
}

if ($sysnet->{internetMode} ne 'none') {
	# check to make sure we have at least one dns server specified
	my @dns_servers = $cce->scalar_to_array($system->{dns});

	if (@dns_servers > 0) {
		# already have dns servers specified
		$cce->bye("SUCCESS");
		exit(0);
	}

	# insert local host as dns server and start the qube's dns
	($ok) = $cce->set($cce->event_oid(), '', { 'dns' => '&127.0.0.1&' });
	
	if (not $ok) {
		$cce->warn("couldntChangeDns");
		$cce->bye("FAIL");
		exit(1);
	}

	($ok) = $cce->set($cce->event_oid(), 'DNS', { 'enabled' => '1' });

	if (not $ok) {
		$cce->warn("couldntStartDns");
		$cce->bye("FAIL");
		exit(1);
	}
}

$cce->bye("SUCCESS");
exit(0);
